@@ -5,8 +5,3 @@ FACEBOOK_APPLICATION_SECRET_KEY = getattr(settings, 'FACEBOOK_APPLICATION_SECRET
 FACEBOOK_APPLICATION_URL = getattr(settings, 'FACEBOOK_APPLICATION_URL')
 DISABLED_PATHS = getattr(settings, 'FANDJANGO_DISABLED_PATHS', [])
 ENABLED_PATHS = getattr(settings, 'FANDJANGO_ENABLED_PATHS', [])
-
-# Alias FANDJANGO_IGNORE_PATHS to DISABLED_PATHS. FANDJANGO_IGNORE_PATHS
-# is deprecated as of v3.4, and will be removed in v3.5.
-if not DISABLED_PATHS:
-    DISABLED_PATHS = getattr(settings, 'FANDJANGO_IGNORE_PATHS', [])
\ No newline at end of file
